==> PyBypass-1.0.4.tar.gz: PyBypass-1.0.4/PyBypass/Constants/regex.py <==
MAIN_REGEX = {
	"https?://(gplinks\.co\/)\S+": ["gplinks", "gplinks_bypass"],
	"https?://(try2link\.com\/)\S+": ["try2link", "try2link_bypass"],
	"https?://(adf\.ly/)\S+": ["adfly", "adfly_bypass"],
	"https?://(bit\.ly\/)\S+": ["bitly", "bitly_bypass"],
	"https?://(ouo\.io\/)\S+": ["ouo", "ouo_bypass"],
	"https?://(ouo\.press\/)\S+": ["ouo", "ouo_bypass"],
	"https?://(shareus\.in\/\?i=)\S+": ["shareus", "shareus_bypass"],
	"https?://(www\.shortly\.xyz\/)\S+": ["shortly", "shortly_bypass"],
	"https?://(tinyurl\.com\/)\S+": ["tinyurl", "tinyurl_bypass"],
	"https?://(thinfi\.com\/)\S+": ["thinfi", "thinfi_bypass"],
	"https?://(hypershort\.com\/)\S+": ["hypershort", "hypershort_bypass"],
	"https?://(safeurl\.sirigan\.my\.id/)\S+": ["sirigan", "sirigan_bypass"],
	"https?://(gtlinks\.me\/)\S+": ["gtlinks", "gtlinks_bypass"],
	"https?://(loan\.kinemaster\.cc\/\?token=)\S+": ["gtlinks", "gtlinks_bypass"],
	"https?://(www\.theforyou\.in\/\?token=)\S+": ["theforyou", "gtlinks_bypass"],
	"https?://(linkvertise\.com/)\S+": ["linkvertise", "linkvertise_bypass"],
	"https?://(shorte|festyy|gestyy|corneey|destyy|ceesty)\.(st|com)\/\S+": ["shortest", "shortest_bypass"],
	
	'https?://(earn4link\.in/)\S+': ['earn4link', 'shortner_type_one_bypass'],
	'https?://(tekcrypt\.in/tek/)\S+': ['tekcrypt', 'shortner_type_one_bypass'],
	'https?://(link\.short2url\.in/)\S+': ['short2url', 'shortner_type_one_bypass'],
	'https?://(go\.rocklinks\.net/)\S+': ['rocklinks', 'shortner_type_one_bypass'],
	'https?://(rocklinks\.net/)\S+': ['rocklinks', 'shortner_type_one_bypass'],
	'https?://(earn\.moneykamalo\.com/)\S+': ['moneykamalo', 'shortner_type_one_bypass'],
	'https?://(m\.easysky\.in/)\S+': ['easysky', 'shortner_type_one_bypass'],
	'https?://(indianshortner\.in/)\S+': ['indianshortner', 'shortner_type_one_bypass'],
	'https?://(open\.crazyblog\.in/)\S+': ['crazyblog', 'shortner_type_one_bypass'],
	'https?://(link\.tnvalue\.in/)\S+': ['tnvalue', 'shortner_type_one_bypass'],
	'https?://(shortingly\.me/)\S+': ['shortingly', 'shortner_type_one_bypass'],
	'https?://(open2get\.in/)\S+': ['open2get', 'shortner_type_one_bypass'],
	'https?://(dulink\.in/)\S+': ['dulink', 'shortner_type_one_bypass'],
	'https?://(bindaaslinks\.com/)\S+': ['bindaaslinks', 'shortner_type_one_bypass'],
	'https?://(za\.uy/)\S+': ['za', 'shortner_type_one_bypass'],
	'https?://(pdiskshortener\.com/)\S+': ['pdiskshortener', 'shortner_type_one_bypass'],
	'https?://(mdiskshortner\.link/)\S+': ['mdiskshortner', 'shortner_type_one_bypass'],
	'https?://(go\.earnl\.xyz/)\S+': ['earnl', 'shortner_type_one_bypass'],
	'https?://(g\.rewayatcafe\.com/)\S+': ['rewayatcafe', 'shortner_type_one_bypass'],
	'https?://(ser2\.crazyblog\.in/)\S+': ['crazyblog', 'shortner_type_one_bypass'],
	'https?://(bitshorten\.com/)\S+': ['bitshorten', 'shortner_type_one_bypass'],
	'http?://(rocklink\.in/)\S+': ['rocklink', 'shortner_type_one_bypass'],
	
	'https?://(droplink\.co/)\S+': ['droplink', 'shortner_type_two_bypass'],
	'https?://(tnlink\.in\/)\S+': ['tnlink', 'shortner_type_two_bypass'],
	'https?://(ez4short\.com/)\S+': ['ez4short', 'shortner_type_two_bypass'],
	'https?://(xpshort\.com/)\S+': ['xpshort', 'shortner_type_two_bypass'],
	'http?://(vearnl\.in/)\S+': ['vearnl', 'shortner_type_two_bypass'],
	'https?://(adrinolinks\.in/)\S+': ['adrinolinks', 'shortner_type_two_bypass'],
	'https?://(techymozo\.com/)\S+': ['techymozo', 'shortner_type_two_bypass'],
	'https?://(linkbnao\.com/)\S+': ['linkbnao', 'shortner_type_two_bypass'],
	'https?://(linksxyz\.in/)\S+': ['linksxyz', 'shortner_type_two_bypass'],
	'https?://(short\-jambo\.com/)\S+': ['short-jambo', 'shortner_type_two_bypass'],
	'https?://(ads\.droplink\.co\.in/)\S+': ['droplink', 'shortner_type_two_bypass'],
	'https?://(linkpays\.in/)\S+': ['linkpays', 'shortner_type_two_bypass'],
	'https?://(pi\-l\.ink/)\S+': ['pi-l', 'shortner_type_two_bypass'],
	'https?://(link\.tnlink\.in/)\S+': ['tnlink', 'shortner_type_two_bypass'],

    'https?://(anonfiles\.com)\S+': ['anonfiles', 'anonfiles_bypass'],
    'https?://(antfiles\.com\/\?dl\=)\S+': ['antfiles', 'antfiles_bypass'],
    'https?://(pjointe|dl4free|tenvoi|piecejointe|mesfichiers|desfichiers|megadl|dfichiers|alterupload|cjoint|1fichier|\.com/\?)\S+': ['1fichier', 'fichier_bypass'],
    'https?://(gofile\.io\/d/)\S+': ['gofile', 'gofile_bypass'],
    'https?://(hxfile\.co/)\S+': ['hxfile', 'hxfile_bypass'],
    'https?://krakenfiles\.com/\S+': ['krakenfiles', 'krakenfiles_bypass'],
    'https?://(mdisk\.me\/convertor)\S+': ['mdisk', 'mdisk_bypass'],
    'https?://(www\.mediafire\.com\/download/)\S+': ['mediafire', 'mediafire_bypass'],
    'https?://(pixeldrain\.com\/(l|u)\/)\S+': ['pixeldrain', 'pixeldrain_bypass'],
    'https?://(racaty\.net/)\S+': ['racaty', 'racaty_bypass'],
    'https?://(send\.cm/)\S+': ['sendcm', 'sendcm_bypass'],
    'https?://(sfile\.mobi/)\S+': ['sfile', 'sfile_bypass'],
    'https?://(www\.solidfiles\.com/v/)\S+': ['solidfiles', 'solidfiles_bypass'],
    'https?://(sourceforge\.net/)\S+': ['sourceforge', 'sourceforge_bypass'],
    'https?://(uploadbaz\.me/)\S+': ['uploadbaz', 'uploadbaz_bypass'],
    'https?://(www\.upload\.ee/)\S+': ['uploadee', 'uploadee_bypass'],
    'https?://(uppit\.com/)\S+': ['uppit', 'uppit_bypass'],
    'https?://(userscloud\.com/)\S+': ['userscloud', 'userscloud_bypass'],
    'https?://(we\.tl/)\S+': ['wetransfer', 'wetransfer_bypass'],
    'https?://(yadi.sk|disk.yandex.com)\S+': ['yandex', 'yandex_bypass'],
    'https?://www\d+\.zippyshare\.com/v/[^/]+/file\.html': ['zippyshare', 'zippyshare_bypass'],

    "https?://(fembed|femax20|fcdn|feurl|naniplay|mm9842|layarkacaxxi|naniplay\.nanime|fembed\-hd)\.(com|net|stream|icu|in|biz)\S+" : ["fembed", "fembed_bypass"],
    "https?://(www\.mp4upload\.com/)\S+": ["mp4upload", "mp4upload_bypass"],
    "https?://(streamlare|sltube\.(com|org)\/v/)\S+":["streamlare", "streamlare_bypass"],
    "https?://(watchsb|streamsb)\.(com|net)\/\S+": ["streamsb", "streamsb_bypass"],
    "https?://(streamtape\.(com|to|xyz)/)\S+": ["streamtape", "streamtape_bypass"],
    
    "https?://(appdrive|driveapp|drivehub|gdflix|drivesharer|drivebit|drivelinks|driveace|drivepro)\.   (info|in|pro|top)\/file/\S+":["appdrive", "appdrive_bypass"],
    "https?://(.+)\.gdtot\.(.+)\/\S+\/\S+" : ["gdtot", "gdtot_bypass"],
    "https?://(hubdrive)\S+": ["hubdrive", "hubdrive_bypass"],
    "https?://(sharer\.pw\/file)\S+": ["sharerpw", "sharerpw_bypass"],

}

==> PyBypass-2.0.0.tar.gz: PyBypass-2.0.0/PyBypass/Constants/regex.py <==
MAIN_REGEX = {
	"https?://(gplinks\.co\/)\S+": ["gplinks", "gplinks_bypass"],
	"https?://(try2link\.com\/)\S+": ["try2link", "try2link_bypass"],
	"https?://(adf\.ly/)\S+": ["adfly", "adfly_bypass"],
	"https?://(bit\.ly\/)\S+": ["bitly", "bitly_bypass"],
	"https?://(ouo\.io\/)\S+": ["ouo", "ouo_bypass"],
	"https?://(ouo\.press\/)\S+": ["ouo", "ouo_bypass"],
	"https?://(shareus\.in\/\?i=)\S+": ["shareus", "shareus_bypass"],
	"https?://(www\.shortly\.xyz\/)\S+": ["shortly", "shortly_bypass"],
	"https?://(tinyurl\.com\/)\S+": ["tinyurl", "tinyurl_bypass"],
	"https?://(thinfi\.com\/)\S+": ["thinfi", "thinfi_bypass"],
	"https?://(hypershort\.com\/)\S+": ["hypershort", "hypershort_bypass"],
	"https?://(safeurl\.sirigan\.my\.id/)\S+": ["sirigan", "sirigan_bypass"],
	"https?://(gtlinks\.me\/)\S+": ["gtlinks", "gtlinks_bypass"],
	"https?://(loan\.kinemaster\.cc\/\?token=)\S+": ["gtlinks", "gtlinks_bypass"],
	"https?://(www\.theforyou\.in\/\?token=)\S+": ["theforyou", "gtlinks_bypass"],
	"https?://(linkvertise\.com/)\S+": ["linkvertise", "linkvertise_bypass"],
	"https?://(shorte|festyy|gestyy|corneey|destyy|ceesty)\.(st|com)\/\S+": ["shortest", "shortest_bypass"],
	"https?://(pkin\.me/)\S+": ["pkin", "pkin_bypass"],

	
	'https?://(tekcrypt\.in/tek/)\S+': ['tekcrypt', 'shortner_type_one_bypass'],
	'https?://(link\.short2url\.in/)\S+': ['short2url', 'shortner_type_one_bypass'],
	'https?://(go\.rocklinks\.net/)\S+': ['rocklinks', 'shortner_type_one_bypass'],
	'https?://(rocklinks\.net/)\S+': ['rocklinks', 'shortner_type_one_bypass'],
	'https?://(earn\.moneykamalo\.com/)\S+': ['moneykamalo', 'shortner_type_one_bypass'],
	'https?://(m\.easysky\.in/)\S+': ['easysky', 'shortner_type_one_bypass'],
	'https?://(indianshortner\.in/)\S+': ['indianshortner', 'shortner_type_one_bypass'],
	'https?://(open\.crazyblog\.in/)\S+': ['crazyblog', 'shortner_type_one_bypass'],
	'https?://(link\.tnvalue\.in/)\S+': ['tnvalue', 'shortner_type_one_bypass'],
	'https?://(shortingly\.me/)\S+': ['shortingly', 'shortner_type_one_bypass'],
	'https?://(dulink\.in/)\S+': ['dulink', 'shortner_type_one_bypass'],
	'https?://(bindaaslinks\.com/)\S+': ['bindaaslinks', 'shortner_type_one_bypass'],
	'https?://(pdiskshortener\.com/)\S+': ['pdiskshortener', 'shortner_type_one_bypass'],
	'https?://(mdiskshortner\.link/)\S+': ['mdiskshortner', 'shortner_type_one_bypass'],
	'https?://(go\.earnl\.xyz/)\S+': ['earnl', 'shortner_type_one_bypass'],
	'https?://(g\.rewayatcafe\.com/)\S+': ['rewayatcafe', 'shortner_type_one_bypass'],
	'https?://(ser2\.crazyblog\.in/)\S+': ['crazyblog', 'shortner_type_one_bypass'],
	'https?://(bitshorten\.com/)\S+': ['bitshorten', 'shortner_type_one_bypass'],
	'http?://(rocklink\.in/)\S+': ['rocklink', 'shortner_type_one_bypass'],
	
	'https?://(droplink\.co/)\S+': ['droplink', 'shortner_type_two_bypass'],
	'https?://(earn4link\.in/)\S+': ['earn4link', 'shortner_type_two_bypass'],
	'https?://(tnlink\.in\/)\S+': ['tnlink', 'shortner_type_two_bypass'],
	'https?://(ez4short\.com/)\S+': ['ez4short', 'shortner_type_two_bypass'],
	'https?://(xpshort\.com/)\S+': ['xpshort', 'shortner_type_two_bypass'],
	'http?://(vearnl\.in/)\S+': ['vearnl', 'shortner_type_two_bypass'],
	'https?://(adrinolinks\.in/)\S+': ['adrinolinks', 'shortner_type_two_bypass'],
	'https?://(techymozo\.com/)\S+': ['techymozo', 'shortner_type_two_bypass'],
	'https?://(linkbnao\.com/)\S+': ['linkbnao', 'shortner_type_two_bypass'],
	'https?://(linksxyz\.in/)\S+': ['linksxyz', 'shortner_type_two_bypass'],
	'https?://(short\-jambo\.com/)\S+': ['short-jambo', 'shortner_type_two_bypass'],
	'https?://(ads\.droplink\.co\.in/)\S+': ['droplink', 'shortner_type_two_bypass'],
	'https?://(linkpays\.in/)\S+': ['linkpays', 'shortner_type_two_bypass'],
	'https?://(pi\-l\.ink/)\S+': ['pi-l', 'shortner_type_two_bypass'],
	'https?://(link\.tnlink\.in/)\S+': ['tnlink', 'shortner_type_two_bypass'],
	'https?://(open2get\.in/)\S+': ['open2get', 'shortner_type_two_bypass'],
	

    'https?://(anonfiles\.com)\S+': ['anonfiles', 'anonfiles_bypass'],
    'https?://(antfiles\.com\/\?dl\=)\S+': ['antfiles', 'antfiles_bypass'],
    'https?://(pjointe|dl4free|tenvoi|piecejointe|mesfichiers|desfichiers|megadl|dfichiers|alterupload|cjoint|1fichier|\.com/\?)\S+': ['1fichier', 'fichier_bypass'],
    'https?://(gofile\.io\/d/)\S+': ['gofile', 'gofile_bypass'],
    'https?://(hxfile\.co/)\S+': ['hxfile', 'hxfile_bypass'],
    'https?://krakenfiles\.com/\S+': ['krakenfiles', 'krakenfiles_bypass'],
    'https?://(mdisk\.me\/convertor)\S+': ['mdisk', 'mdisk_bypass'],
    'https?://(www\.mediafire\.com\/download/)\S+': ['mediafire', 'mediafire_bypass'],
    'https?://(pixeldrain\.com\/(l|u)\/)\S+': ['pixeldrain', 'pixeldrain_bypass'],
    'https?://(racaty\.(net|io)/)\S+': ['racaty', 'racaty_bypass'],
    'https?://(send\.cm/)\S+': ['sendcm', 'sendcm_bypass'],
    'https?://(sfile\.mobi/)\S+': ['sfile', 'sfile_bypass'],
    'https?://(www\.solidfiles\.com/v/)\S+': ['solidfiles', 'solidfiles_bypass'],
    'https?://(sourceforge\.net/)\S+': ['sourceforge', 'sourceforge_bypass'],
    'https?://(uploadbaz\.me/)\S+': ['uploadbaz', 'uploadbaz_bypass'],
    'https?://(www\.upload\.ee/)\S+': ['uploadee', 'uploadee_bypass'],
    'https?://(uppit\.com/)\S+': ['uppit', 'uppit_bypass'],
    'https?://(userscloud\.com/)\S+': ['userscloud', 'userscloud_bypass'],
    'https?://(we\.tl/)\S+': ['wetransfer', 'wetransfer_bypass'],
    'https?://(yadi.sk|disk.yandex.com)\S+': ['yandex', 'yandex_bypass'],
    'https?://www\d+\.zippyshare\.com/v/[^/]+/file\.html': ['zippyshare', 'zippyshare_bypass'],

    "https?://(fembed|femax20|fcdn|feurl|naniplay|mm9842|layarkacaxxi|naniplay\.nanime|fembed\-hd)\.(com|net|stream|icu|in|biz)\S+" : ["fembed", "fembed_bypass"],
    "https?://(www\.mp4upload\.com/)\S+": ["mp4upload", "mp4upload_bypass"],
    "https?://(streamlare|sltube\.(com|org)\/v/)\S+":["streamlare", "streamlare_bypass"],
    "https?://(watchsb|streamsb)\.(com|net)\/\S+": ["streamsb", "streamsb_bypass"],
    "https?://(streamtape\.(com|to|xyz)/)\S+": ["streamtape", "streamtape_bypass"],
    
    "https?://(appdrive|driveapp|drivehub|gdflix|drivesharer|drivebit|drivelinks|driveace|drivepro)\.(info|in|pro|top)\/file/\S+":["appdrive","appdrive_bypass"],
    "https?://(.+)\.gdtot\.(.+)\/\S+\/\S+" : ["gdtot", "gdtot_bypass"],
    "https?://(hubdrive)\S+": ["hubdrive", "hubdrive_bypass"],
    "https?://(sharer\.pw\/file)\S+": ["sharerpw", "sharerpw_bypass"],

}
